<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2004 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****

# Change here the template lang
//$__lang = 'fr';

# Ajout des fichiers du template pour le cache
$mod_files[] = dirname(__FILE__).'/list.php';
$mod_files[] = dirname(__FILE__).'/post.php';
$mod_files[] = dirname(__FILE__).'/form.php';
$mod_files[] = dirname(__FILE__).'/home.php';
$mod_files[] = dirname(__FILE__).'/style.php';

// Lecture de la configuration. En cas d'absence de fichier .ini, on utilise des valeurs par dfaut.
$cfg_file = DC_SHARE_DIR.'/photoblog/photoblog.ini';
$photo_cat_order_chrono   = false;
$photo_month_order_chrono = false;
$photo_nav_nb_prev_thumbs = 3;
$photo_nav_nb_next_thumbs = 3;

if (@file_exists($cfg_file)) {
	$photoblog_cfg = iniFile::read($cfg_file, true);
	$photo_cat_order_chrono   = $photoblog_cfg['sp_archive_cat_chrono_order'];
	$photo_month_order_chrono = $photoblog_cfg['sp_archive_month_chrono_order'];
	$photo_nav_nb_prev_thumbs = $photoblog_cfg['sp_nav_nb_prev_thumbs'];
	$photo_nav_nb_next_thumbs = $photoblog_cfg['sp_nav_nb_next_thumbs'];
}

/**
 * dcWikiCommentToolbar([string $message])
 * 
 * Affiche un barre d'outils pour la mise en forme des commentaires
 * au format wiki.
 * La barre ne sera affichée que si le format wiki des commentaires
 * est activé dans le fichier de configuration dotclear.ini.
 *
 * ( Reportez vous au fichier install.html présent dans l'archive de
 *   la wikibarre. )
 *
 * @param string $message un message d'information optionnel.
 *
 */
function dcWikiCommentToolbar($message = '') {
	global $theme_path, $theme_uri, $__theme;
	
	if (is_dir($theme_path.$__theme.'/wikibtns/')) {
		$dc_url_wikibuttons = $theme_uri.$__theme.'/wikibtns/';
	} else {
		$dc_url_wikibuttons = $theme_uri.'default/wikibtns/';
	}
	if (file_exists($theme_path.$__theme.'/js/wikibar.js')) {
		$dc_url_wikijs = $theme_uri.$__theme.'/js/wikibar.js';
	} else {
		$dc_url_wikijs = $theme_uri.'default/js/wikibar.js';
	}
	if (dc_wiki_comments) {
		echo '<script type="text/javascript" src="'.$dc_url_wikijs.'"></script>'. "\n".
'<script type="text/javascript">'. "\n".
"	if (document.getElementById) {
		var tb = new dcWikiBar(document.getElementById('c_content'),'$dc_url_wikibuttons');
	
		tb.btStrong('".str_replace("'","\'",__('Strong emphasis'))."');
		tb.btEm('".str_replace("'","\'",__('Emphasis'))."');
		tb.btIns('".str_replace("'","\'",__('Inserted'))."');
		tb.btDel('".str_replace("'","\'",__('Deleted'))."');
		tb.btQ('".str_replace("'","\'",__('Inline quote'))."');
		tb.btCode('".str_replace("'","\'",__('Code'))."');
		tb.btBr('".str_replace("'","\'",__('Line break'))."');
		tb.btPre('".str_replace("'","\'",__('Preformated text'))."');
		tb.btList('".str_replace("'","\'",__('Unordered list'))."','ul');
		tb.btList('".str_replace("'","\'",__('Ordered list'))."','ol');
		tb.btLink('".str_replace("'","\'",__('Link'))."',
			'".str_replace("'","\'",__('URL?'))."',
			'".str_replace("'","\'",__('Language?'))."',
			'".DC_LANG."');
		tb.addSpace(10);
		tb.draw('$message');
	}
</script>\n";
	}
}

/**
	Rcuprer les catgories, sans qu'elles aient besoin d'tre lies  un billet.
  @function dcMyGetCat
*/
function dcMyGetCat($cat_id='', $order_by='cat_ord') {
	global $blog;

	$reqPlus = '';

	if ($cat_id != '') {
		if (preg_match('/^[0-9]+$/',$cat_id)) {
			$reqPlus .= 'AND C.cat_id = '.$blog->con->escapeStr($cat_id).' ';
		} else {
			$reqPlus .= 'AND C.cat_libelle_url = \''.$blog->con->escapeStr($cat_id).'\' ';
		}
	}

	$strReq = 'SELECT C.cat_id, cat_libelle, cat_desc, cat_libelle_url '.
			'FROM '.$blog->t_categorie.' C '.
			'WHERE 1 '.
			$reqPlus.
			'GROUP BY C.cat_id '.
			'ORDER BY '.$blog->con->escapeStr($order_by);

	if (($rs =$blog->con->select($strReq)) !== false) {
		return $rs;
	} else {
		$blog->setError('MySQL : '.$blog->con->error(),2000);
		return false;
	}

}

/**
Rcuprer le titre de la catgorie et sa description, lui affecter un style (merci Nikikko)
@function dcMyCatTop
*/
function dcMyCatTop($block='<div class="titrecat cat%3$s"><p>%2$s</p></div>')
{
	global $blog;
	global $cat_id;

	$cat = dcMyGetCat($cat_id);

	printf($block,$cat->f('cat_libelle'),$cat->f('cat_desc'),$cat->f('cat_libelle_url'));
}

/* Conversion d'une chaine UTF-8 en remplacant tous les caracteres accentues par leur valeur
   numerique HTML. Source : http://www.php.net/manual/en/function.imagettftext.php#57416 */
define('EMPTY_STRING', '');

function foxy_utf8_to_nce($utf = EMPTY_STRING)
{
	if($utf == EMPTY_STRING) return($utf);

	$max_count = 5; // flag-bits in $max_mark ( 1111 1000 == 5 times 1)
	$max_mark = 248; // marker for a (theoretical ;-)) 5-byte-char and mask for a 4-byte-char;

	$html = EMPTY_STRING;
	for($str_pos = 0; $str_pos < strlen($utf); $str_pos++) {
		$old_chr = $utf{$str_pos};
		$old_val = ord( $utf{$str_pos} );
		$new_val = 0;

		$utf8_marker = 0;

		// skip non-utf-8-chars
		if( $old_val > 127 ) {
			$mark = $max_mark;
			for($byte_ctr = $max_count; $byte_ctr > 2; $byte_ctr--) {
				// actual byte is utf-8-marker?
				if( ( $old_val & $mark  ) == ( ($mark << 1) & 255 ) ) {
					$utf8_marker = $byte_ctr - 1;
					break;
				}
				$mark = ($mark << 1) & 255;
			}
		}

		// marker found: collect following bytes
		if($utf8_marker > 1 and isset( $utf{$str_pos + 1} ) ) {
			$str_off = 0;
			$new_val = $old_val & (127 >> $utf8_marker);
			for($byte_ctr = $utf8_marker; $byte_ctr > 1; $byte_ctr--) {

				// check if following chars are UTF8 additional data blocks
				// UTF8 and ord() > 127
				if( (ord($utf{$str_pos + 1}) & 192) == 128 ) {
					$new_val = $new_val << 6;
					$str_off++;
					// no need for Addition, bitwise OR is sufficient
					// 63: more UTF8-bytes; 0011 1111
					$new_val = $new_val | ( ord( $utf{$str_pos + $str_off} ) & 63 );
				}
				// no UTF8, but ord() > 127
				// nevertheless convert first char to NCE
				else {
					$new_val = $old_val;
				}
			}
			// build NCE-Code
			$html .= '&#'.$new_val.';';
			// Skip additional UTF-8-Bytes
			$str_pos = $str_pos + $str_off;
		}
		else {
			$html .= chr($old_val);
			$new_val = $old_val;
		}
	}
	return($html);
}

/* Fonctions myWordWrap et create_title tirees du theme tutti-frutti par La lne (jeuxdemaux.com) et Bastien Bobe (gougueule.net) */

function myWordWrap($txt,$font,$size,$width)
{
	// Dfinition du nombre de ligne de l'image
	$nbre_ligne = 1;

	/*
	  word-wrapper.  gets bounding box sizes for each word in a string, then
	  strings words together up to desired width. calls strpos and
	  imagettfbbox only once per word - so very fast.
	  this version reconcatenates the words with a <br> character where
	  the line break should be.
	 */
	$txt.=" ";
	// guaranteed to find end of line
	$spaces=array();
	$wids=array();
	$i=0;
	while (true) {
		$j=strpos(substr($txt,$i)," ");
		if (!($j===false)) {
			$spaces[]=$j+$i;
			@$bbox=imagettfbbox($size,0,$font,substr($txt,$i,$j+1));
			$left=($bbox[0]>$bbox[6])?$bbox[6]:$bbox[0];
			$right=($bbox[2]>$bbox[4])?$bbox[2]:$bbox[4];
			$wids[]=$right-$left;
			$i=$j+$i+1;
		} else {
			break;
		}
	}
	$lastspace=-1;
	$cum=0;
	$t2="";
	for ($i=0; $i<count($spaces); $i++) {
		if((($cum>0)&&($cum+$wids[$i])>$width)) // time for a line break
		{
			$t2.="\n";
			$nbre_ligne++;
			$cum=0;
			$i--;
		} else {
			// we'll always get at least one word (even if too wide) thanks to
			// ($cum>0) test above
			$t2.=substr($txt,$lastspace+1,$spaces[$i]-$lastspace);
			$cum+=$wids[$i];
			$lastspace=$spaces[$i];
		}
	}

	$image_created = array("$t2","$nbre_ligne");
	return $image_created;
}

function create_title($titre,$couleur_texte,$couleur_fond,$taille_texte,$chemin_police)
{
//	echo "Chemin police : $chemin_police";

	//Dfinition de la largeur maximum de l'image gnre
	$width_max = 700;

	//Dfinition du nom de l'image en fonction du titre et des attributs passs dans la fonction
	$titre_affiche = ' ' . $titre;
	$titre_affiche = @html_entity_decode($titre_affiche, ENT_COMPAT, 'ISO-8859-15');
	// Conversion en UTF-8
	$titre_affiche = utf8_encode($titre_affiche);
	// Conversion des caracteres accentues en leur equivalent numerique
	$titre_affiche = foxy_utf8_to_nce($titre_affiche);

	$nom_image = md5($titre.$chemin_police.$taille_texte.$couleur_fond.$couleur_texte);

	$chemin_repertoire = dcPhotoBlog::getImagePath() . "/titres";

	if (!file_exists($chemin_repertoire)) {
		@mkdir($chemin_repertoire,0777) or die("Impossible de crer le rpertoire d'image titre '$chemin_repertoire'");
	}

	$chemin_image = $chemin_repertoire.'/'.$nom_image.'.png';

	if (!file_exists($chemin_image)) {

		// Test de la taille de l'image et dfinition du nombre de ligne
		list($titre_image, $nbre_ligne) = myWordWrap($titre_affiche, $chemin_police, $taille_texte, $width_max);

		// Calcul de la taille de l'image
		$taille_image = imagettfbbox($taille_texte, 0, $chemin_police, "$titre_image");
		$taille_image_largeur = (abs($taille_image[0])+abs($taille_image[2])+5);
		if ($taille_image_largeur > $width_max) {
			$taille_image_largeur = $width_max;
		}
		$taille_image_hauteur = (abs($taille_image[5])+abs($taille_image[7])) * $nbre_ligne;
		$hauteur_ligne = abs($taille_image[5])+abs($taille_image[7]);

		// Cration du cadre d'image
		$img = imagecreate($taille_image_largeur,$taille_image_hauteur);

		// Dfinition de la couleur du texte
		$couleur_texte = hexdec(str_replace('#','',$couleur_texte));
		$couleur_texte = imagecolorallocate($img,($couleur_texte & 0xFF0000) >> 16,($couleur_texte & 0x00FF00) >> 8,($couleur_texte & 0x0000FF));

		// Dfinition de la couleur du fond
		$couleur_fond = hexdec(str_replace('#','',$couleur_fond));
		$couleur_fond = imagecolorallocate($img,($couleur_fond & 0xFF0000) >> 16,($couleur_fond & 0x00FF00) >> 8,($couleur_fond & 0x0000FF));

		// Remplissage du fond de l'image avec la couleur dfinie avant et affectation de la transparence
		imagefill($img,0,0,$couleur_fond);
		imagecolortransparent($img, $couleur_fond);

		// Ajout du texte, affichage ligne par ligne si le texte comporte plus d'une ligne
		if ($nbre_ligne > 1) {
			$titre_image = explode("\n", $titre_image);
			$i = 0;
			while ($i != $nbre_ligne) {
				@imagettftext($img, $taille_texte, 0, 0, $taille_texte + ($hauteur_ligne*$i), $couleur_texte, $chemin_police, $titre_image[$i]);
				$i++;
			}
		} else {
			@imagettftext($img, $taille_texte, 0, 0, $taille_texte, $couleur_texte, $chemin_police, "$titre_image");
		}

		// Cration de l'image et criture sur le serveur
		@imagepng($img,$chemin_image) or die("Impossible d'crire dans le rpertoire d'images...");
		imagedestroy($img);
		chmod($chemin_image, 0666);

	}

	$chemin_image_web = dc_img_url."titres/".$nom_image.".png";

	if (file_exists($chemin_image)) {
		$taille_image = getimagesize($chemin_image);
		$taille_image_largeur = $taille_image[0];
		$taille_image_hauteur = $taille_image[1];
		echo "<span style=\"display:none\">$titre</span><img src=\"".$chemin_image_web."\" style=\"border:0px;\" alt=\"$titre\" />";
		//width:".$taille_image_largeur."px;height:".$taille_image_hauteur."px;\" /></span>";
	} else {
		echo $titre;
	}
}

/**
@function dcCall

Cette fonction est un simple wrapper pour les appels aux mthodes
additionnelles mises en oeuvre par les plugins.
Elle permet d'envisager l'appel aux fonctions d'un plugin sans que
cela ne pose problme en cas d'absence du dit plugin.

liste d'arguments variable.
@param	string	plugin_method
@param	mixed	method_arguments
*/
if (!function_exists('dcCall')) 
{
	function dcCall()
	{
		if (!func_num_args() == 0)
		{
			$args = func_get_args();
			$call = array_shift($args);
			$method_call = explode('::', $call);
	
			switch (count($method_call))
			{
				case 1  : $call = $method_call[0]; $callable = function_exists($call); break;
				case 2  : $call = $method_call; $callable = is_callable($call, false); break;
				default : $callable = false; break;
			}
	
			if ($callable)
			{
				return(call_user_func_array($call, $args));
			}
		}
		return false;
	}
}

# Compatibilite pour une version de DotClear inferieure a 1.2.1
if (!function_exists('dcCustomTitle')) {
	/**
	@function dcCustomTitle
	
	Cette fonction affiche le contenu de la variable globale $dc_custom_title.
	Cette variable peut-etre assignee par un plugin.
	
	@param string s Chaine de substitution ('%s - ')
	*/
	function dcCustomTitle($s='%s - ') {
		if (!empty($GLOBALS['dc_custom_title'])) {
			printf($s,$GLOBALS['dc_custom_title']);
		}
	}
}
	
function getArchiveTitle()
{
	if (!is_callable(array('dcPhotoBlog', 'getArchiveTitle'), false)) {
		global $year, $month, $cat_id_photo, $blog, $cat_id, $con;

		if (($cat_id_photo != '') || ($cat_id != '')) {
			$my_cat = $cat_id_photo == '' ? $cat_id : $cat_id_photo;
			$SQL = 'SELECT cat_libelle FROM ' . $blog->t_categorie . ' WHERE cat_libelle_url = \'' . $my_cat . "'";
			$rs_cat = $con->select($SQL);

			$title = $rs_cat->f('cat_libelle');
			if ($year > 0 && $month == '') {
				$title .= ", $year";
			} else if ($year > 0 && $month > 0 && $month < 13) {
				$title .= ', ' . strtolower(dt::str('%B', strtotime("2000-$month-01"))) . " $year";
			}
		} else {
			$title = ucwords(dt::str('%B', strtotime("2000-$month-01"))) . ' ' . $year;
		}
		return $title;
	} else {
		return dcPhotoBlog::getArchiveTitle();
	}
}

?>
